@@ -22,11 +22,11 @@ VSGDR::StaticData - Static data script support package for SSDT post-deployment
 
 =head1 VERSION
 
-Version 0.31
+Version 0.32
 
 =cut
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 
 sub databaseName {
@@ -289,13 +289,13 @@ sub generateScript {
 #    my $ra_data = getCurrentTableData($dbh,$quotedCombinedName    ,$pk_column,$flatcolumnlist);
     my $ra_data = getCurrentTableData($dbh,$quotedCombinedName    ,$pk_column,$flatExtractColumnList);
     
-    my @valuesTable     = undef;
+    my @valuesTable     ;
     my $valuesClause    = "values\n\t\t\t";
 
     my $lno             = 1;
     foreach my $ra_row (@{$ra_data}){
     #    warn Dumper $ra_row;
-        my @outVals = () ;
+        my @outVals = undef ;
 #warn Dumper @{$ra_row} ;        
 #exit;
         for ( my $i = 0; $i < scalar @{$ra_row}; $i++ ) {
@@ -321,11 +321,48 @@ sub generateScript {
                 }
             }
         }
+        push @valuesTable, \@outVals ;
         #my @outVals = map { $ColumnNumericity{$_} == 1 ? $_ : $dbh->quote($_)  } @{$ra_row};
         my $line = do{ local $" = ", "; "@outVals" } ;
-        $valuesClause    .= "(\t" . $line . ")" . "\n\t\t,\t" ;
+        #$valuesClause    .= "(\t" . $line . ")" . "\n\t\t,\t" ;
         $lno++;
     }
+
+    my @maxWidth;
+    my $maxCol;
+    
+    if ( scalar @valuesTable ) {
+        my @tmp = @{$valuesTable[0]};
+        $maxCol = scalar @tmp -1 ;
+        for ( my $i = 0; $i <= $maxCol; $i++ ) {
+            push @maxWidth, 0;
+        }     
+        for ( my $i = 0; $i < scalar @valuesTable; $i++ ) {
+            my @tmp = @{$valuesTable[$i]};
+            for ( my $i = 0; $i <= $maxCol; $i++ ) {
+                if (length($tmp[$i]) > $maxWidth[$i] ) {
+                    $maxWidth[$i] = length($tmp[$i]) ;
+                }
+            }
+        }
+    }
+    
+    #warn Dumper @maxWidth ;
+    
+    for ( my $i = 0; $i < scalar @valuesTable; $i++ ) {
+        my @tmp = @{$valuesTable[$i]};
+        my $line = "";
+        for ( my $j = 0; $j <= $maxCol; $j++ ) {
+            my $val    = $tmp[$j];
+            my $valWidth = length($val);
+            my $PadLength = $maxWidth[$j]-$valWidth;
+            my $padding = " "x$PadLength;
+            $line .= ", ${padding}${val}";
+        }
+        $line =~ s{ ^,\s}{}msx;
+        $valuesClause    .= "(\t" . $line . ")" . "\n\t\t,\t" ;
+    }
+
     $valuesClause        =~ s{ \n\t\t,\t \z }{}msx;
     
 
